==> haskell-singletons-3.0.2-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-singletons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singletons
version:              3.0.2
visibility:           public
id:                   singletons-3.0.2-7IYM5dOgAgzCocY7YGPMos
key:                  singletons-3.0.2-7IYM5dOgAgzCocY7YGPMos
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:
    Richard Eisenberg <rae@cs.brynmawr.edu>, Jan Stolarek <jan.stolarek@p.lodz.pl>

stability:            experimental
homepage:             http://www.github.com/goldfirere/singletons
synopsis:             Basic singleton types and definitions
description:
    @singletons@ contains the basic types and definitions needed to support
    dependently typed programming techniques in Haskell. This library was
    originally presented in /Dependently Typed Programming with Singletons/,
    published at the Haskell Symposium, 2012.
    (<https://richarde.dev/papers/2012/singletons/paper.pdf>)

    @singletons@ is intended to be a small, foundational library on which other
    projects can build. As such, @singletons@ has a minimal dependency
    footprint and supports GHCs dating back to GHC 8.0. For more information,
    consult the @singletons@
    @<https://github.com/goldfirere/singletons/blob/master/README.md README>@.

    You may also be interested in the following related libraries:

    * The @singletons-th@ library defines Template Haskell functionality that
    allows /promotion/ of term-level functions to type-level equivalents and
    /singling/ functions to dependently typed equivalents.

    * The @singletons-base@ library uses @singletons-th@ to define promoted and
    singled functions from the @base@ library, including the "Prelude".

category:             Dependent Types
abi:                  2de75a567715f0233c02525f5bab9022
exposed:              True
exposed-modules:
    Data.Singletons Data.Singletons.Decide Data.Singletons.ShowSing
    Data.Singletons.Sigma

import-dirs:          /usr/lib/ghc-9.2.8/site-local/singletons-3.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/singletons-3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singletons
hs-libraries:         HSsingletons-3.0.2-7IYM5dOgAgzCocY7YGPMos
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-singletons/html/singletons.haddock
haddock-html:         /usr/share/doc/haskell-singletons/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singletons-3.0.4-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-singletons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singletons
version:              3.0.4
visibility:           public
id:                   singletons-3.0.4-5pDsUnwe3c7FZQt4Yt8MEN
key:                  singletons-3.0.4-5pDsUnwe3c7FZQt4Yt8MEN
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:
    Richard Eisenberg <rae@cs.brynmawr.edu>, Jan Stolarek <jan.stolarek@p.lodz.pl>

stability:            experimental
homepage:             http://www.github.com/goldfirere/singletons
synopsis:             Basic singleton types and definitions
description:
    @singletons@ contains the basic types and definitions needed to support
    dependently typed programming techniques in Haskell. This library was
    originally presented in /Dependently Typed Programming with Singletons/,
    published at the Haskell Symposium, 2012.
    (<https://richarde.dev/papers/2012/singletons/paper.pdf>)

    @singletons@ is intended to be a small, foundational library on which other
    projects can build. As such, @singletons@ has a minimal dependency
    footprint and supports GHCs dating back to GHC 8.0. For more information,
    consult the @singletons@
    @<https://github.com/goldfirere/singletons/blob/master/README.md README>@.

    You may also be interested in the following related libraries:

    * The @singletons-th@ library defines Template Haskell functionality that
    allows /promotion/ of term-level functions to type-level equivalents and
    /singling/ functions to dependently typed equivalents.

    * The @singletons-base@ library uses @singletons-th@ to define promoted and
    singled functions from the @base@ library, including the "Prelude".

category:             Dependent Types
abi:                  25c0ad06130446728fa1bba0d45d6904
exposed:              True
exposed-modules:
    Data.Singletons Data.Singletons.Decide Data.Singletons.ShowSing
    Data.Singletons.Sigma

import-dirs:          /usr/lib/ghc-9.4.8/site-local/singletons-3.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/singletons-3.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/singletons-3.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singletons
hs-libraries:         HSsingletons-3.0.4-5pDsUnwe3c7FZQt4Yt8MEN
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-singletons/html/singletons.haddock
haddock-html:         /usr/share/doc/haskell-singletons/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
